==> dcl-5.1-C.tar.gz: dcl-5.1-C/src/misc1/chnlib/chngi.c <==
/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
/* chngi.f -- translated by f2c (version 19990503).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "f2c.h"

/* Table of constant values */

static integer c__1 = 1;
static integer c__3 = 3;

/* ----------------------------------------------------------------------- */
/* Subroutine */ int chngi_(char *ch, char *ca, integer *ii, char *cfmt, 
	ftnlen ch_len, ftnlen ca_len, ftnlen cfmt_len)
{
    /* System generated locals */
    address a__1[3];
    integer i__1, i__2[3];
    char ch__1[107];
    icilist ici__1;

    /* Builtin functions */
    integer i_len(char *, ftnlen);
    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
	     char **, integer *, integer *, ftnlen);
    integer s_wsfi(icilist *), do_fio(integer *, char *, ftnlen), e_wsfi(void)
	    ;

    /* Local variables */
    static char cpat[80];
    static integer nh, nn;
    extern integer indxnf_(char *, integer *, integer *, char *, ftnlen, 
	    ftnlen);
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen);
    static integer id1, id2, ios;

    nh = i_len(ch, ch_len);
    nn = i_len(ca, ca_len);
    s_copy(cpat, ca, (ftnlen)80, nn);
    if (! (nh >= nn)) {
	msgdmp_("E", "CHNGI", "TEXT LENGTH IS TOO SHORT.", (ftnlen)1, (ftnlen)
		5, (ftnlen)25);
    }
    i__1 = nh - nn + 1;
    id1 = indxnf_(ch, &i__1, &c__1, ca, ch_len, ca_len);
    id2 = id1 + nn - 1;
    if (id1 == 0) {
/* Writing concatenation */
	i__2[0] = 10, a__1[0] = "PATTERN < ";
	i__2[1] = nn, a__1[1] = cpat;
	i__2[2] = 17, a__1[2] = " > WAS NOT FOUND.";
	s_cat(ch__1, a__1, i__2, &c__3, (ftnlen)107);
	msgdmp_("W", "CHNGI", ch__1, (ftnlen)1, (ftnlen)5, nn + 27);
    } else {
	ici__1.icierr = 1;
	ici__1.icirnum = 1;
	ici__1.icirlen = id2 - (id1 - 1);
	ici__1.iciunit = ch + (id1 - 1);
	ici__1.icifmt = cfmt;
	ios = s_wsfi(&ici__1);
	if (ios != 0) {
	    goto L100001;
	}
	ios = do_fio(&c__1, (char *)&(*ii), (ftnlen)sizeof(integer));
	if (ios != 0) {
	    goto L100001;
	}
	ios = e_wsfi();
L100001:
	if (ios != 0) {
	    msgdmp_("W", "CHNGI", "SUBSTITUTION ERROR.", (ftnlen)1, (ftnlen)5,
		     (ftnlen)19);
	}
    }
    return 0;
} /* chngi_ */

==> dcl-6.0.0-C.tar.gz: dcl-6.0.0-C/src/misc1/chnlib/chngi.c <==
/*  -- translated by f2c (version 20100827).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__1 = 1;
static integer c__3 = 3;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int chngi_(char *ch, char *ca, integer *ii, char *cfmt, 
	ftnlen ch_len, ftnlen ca_len, ftnlen cfmt_len)
{
    /* System generated locals */
    address a__1[3];
    integer i__1, i__2[3];
    char ch__1[107];
    icilist ici__1;

    /* Builtin functions */
    integer i_len(char *, ftnlen);
    /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
	     char **, integer *, integer *, ftnlen);
    integer s_wsfi(icilist *), do_fio(integer *, char *, ftnlen), e_wsfi(void)
	    ;

    /* Local variables */
    static integer nh, nn, id1, id2, ios;
    static char cpat[80];
    extern integer indxnf_(char *, integer *, integer *, char *, ftnlen, 
	    ftnlen);
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen);

    nh = i_len(ch, ch_len);
    nn = i_len(ca, ca_len);
    s_copy(cpat, ca, (ftnlen)80, nn);
    if (! (nh >= nn)) {
	msgdmp_("E", "CHNGI", "TEXT LENGTH IS TOO SHORT.", (ftnlen)1, (ftnlen)
		5, (ftnlen)25);
    }
    i__1 = nh - nn + 1;
    id1 = indxnf_(ch, &i__1, &c__1, ca, ch_len, ca_len);
    id2 = id1 + nn - 1;
    if (id1 == 0) {
/* Writing concatenation */
	i__2[0] = 10, a__1[0] = "PATTERN < ";
	i__2[1] = nn, a__1[1] = cpat;
	i__2[2] = 17, a__1[2] = " > WAS NOT FOUND.";
	s_cat(ch__1, a__1, i__2, &c__3, (ftnlen)107);
	msgdmp_("W", "CHNGI", ch__1, (ftnlen)1, (ftnlen)5, nn + 27);
    } else {
	ici__1.icierr = 1;
	ici__1.icirnum = 1;
	ici__1.icirlen = id2 - (id1 - 1);
	ici__1.iciunit = ch + (id1 - 1);
	ici__1.icifmt = cfmt;
	ios = s_wsfi(&ici__1);
	if (ios != 0) {
	    goto L100001;
	}
	ios = do_fio(&c__1, (char *)&(*ii), (ftnlen)sizeof(integer));
	if (ios != 0) {
	    goto L100001;
	}
	ios = e_wsfi();
L100001:
	if (ios != 0) {
	    msgdmp_("W", "CHNGI", "SUBSTITUTION ERROR.", (ftnlen)1, (ftnlen)5,
		     (ftnlen)19);
	}
    }
    return 0;
} /* chngi_ */
